diff --git a/index.html b/index.html
index aa42957a4c..7dcebd2b76 100644
--- a/index.html
+++ b/index.html
@@ -27,7 +27,7 @@
display: block !important;
}
-
+
diff --git a/32013.625b7b67.async.js b/32013.fe5a38bc.async.js
similarity index 89%
rename from 32013.625b7b67.async.js
rename to 32013.fe5a38bc.async.js
index 9cd4640a82..0570002771 100644
--- a/32013.625b7b67.async.js
+++ b/32013.fe5a38bc.async.js
@@ -9,6 +9,8 @@
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */ AY: function() { return /* binding */ purchases_review; },
+/* harmony export */ B5: function() { return /* binding */ del_specialist; },
+/* harmony export */ CV: function() { return /* binding */ edit_specialist; },
/* harmony export */ ER: function() { return /* binding */ tracks_info; },
/* harmony export */ EZ: function() { return /* binding */ receives_create; },
/* harmony export */ FA: function() { return /* binding */ substance_details_scrapped; },
@@ -17,8 +19,10 @@
/* harmony export */ Gf: function() { return /* binding */ submit_substance_details; },
/* harmony export */ HM: function() { return /* binding */ substances_query; },
/* harmony export */ HX: function() { return /* binding */ substance_categories_delete; },
+/* harmony export */ I_: function() { return /* binding */ getSpecialists; },
/* harmony export */ JQ: function() { return /* binding */ receives_cancel; },
/* harmony export */ K$: function() { return /* binding */ bills_create; },
+/* harmony export */ LI: function() { return /* binding */ get_duty_info; },
/* harmony export */ M1: function() { return /* binding */ bills_delete; },
/* harmony export */ NP: function() { return /* binding */ new_substance_create_details; },
/* harmony export */ OV: function() { return /* binding */ me_substances_query; },
@@ -42,6 +46,7 @@
/* harmony export */ pd: function() { return /* binding */ purchases_canceled; },
/* harmony export */ vH: function() { return /* binding */ receives_review; },
/* harmony export */ vR: function() { return /* binding */ scene_receives_create; },
+/* harmony export */ wr: function() { return /* binding */ add_specialists; },
/* harmony export */ xR: function() { return /* binding */ substances_update; },
/* harmony export */ xb: function() { return /* binding */ substance_categories_query; },
/* harmony export */ y_: function() { return /* binding */ substance_details_update; },
@@ -49,7 +54,7 @@
/* harmony export */ zG: function() { return /* binding */ purchases_info; },
/* harmony export */ zO: function() { return /* binding */ me_receives_query; }
/* harmony export */ });
/* unused harmony exports substances_list, code_download, code_batch_download, receives_matches */
/* harmony import */ var _root_workspace_ppte5yg23_local_v9_test4_node_modules_babel_runtime_7_23_6_babel_runtime_helpers_regeneratorRuntime_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/_@babel_runtime@7.23.6@@babel/runtime/helpers/regeneratorRuntime.js */ 7557);
/* harmony import */ var _root_workspace_ppte5yg23_local_v9_test4_node_modules_babel_runtime_7_23_6_babel_runtime_helpers_regeneratorRuntime_js__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_root_workspace_ppte5yg23_local_v9_test4_node_modules_babel_runtime_7_23_6_babel_runtime_helpers_regeneratorRuntime_js__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _root_workspace_ppte5yg23_local_v9_test4_node_modules_babel_runtime_7_23_6_babel_runtime_helpers_objectSpread2_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/_@babel_runtime@7.23.6@@babel/runtime/helpers/objectSpread2.js */ 82242);
@@ -1003,6 +1008,8 @@ function _receives_update() {
function random_number(_x44) {
return _random_number.apply(this, arguments);
}
+
+//添加专家
function _random_number() {
_random_number = _root_workspace_ppte5yg23_local_v9_test4_node_modules_babel_runtime_7_23_6_babel_runtime_helpers_asyncToGenerator_js__WEBPACK_IMPORTED_MODULE_2___default()( /*#__PURE__*/_root_workspace_ppte5yg23_local_v9_test4_node_modules_babel_runtime_7_23_6_babel_runtime_helpers_regeneratorRuntime_js__WEBPACK_IMPORTED_MODULE_0___default()().mark(function _callee44(params) {
return _root_workspace_ppte5yg23_local_v9_test4_node_modules_babel_runtime_7_23_6_babel_runtime_helpers_regeneratorRuntime_js__WEBPACK_IMPORTED_MODULE_0___default()().wrap(function _callee44$(_context44) {
@@ -1020,6 +1027,136 @@ function _random_number() {
}));
return _random_number.apply(this, arguments);
}
+function add_specialists(_x45) {
+ return _add_specialists.apply(this, arguments);
+}
+
+//获取专家列表
+function _add_specialists() {
+ _add_specialists = _root_workspace_ppte5yg23_local_v9_test4_node_modules_babel_runtime_7_23_6_babel_runtime_helpers_asyncToGenerator_js__WEBPACK_IMPORTED_MODULE_2___default()( /*#__PURE__*/_root_workspace_ppte5yg23_local_v9_test4_node_modules_babel_runtime_7_23_6_babel_runtime_helpers_regeneratorRuntime_js__WEBPACK_IMPORTED_MODULE_0___default()().mark(function _callee45(data) {
+ return _root_workspace_ppte5yg23_local_v9_test4_node_modules_babel_runtime_7_23_6_babel_runtime_helpers_regeneratorRuntime_js__WEBPACK_IMPORTED_MODULE_0___default()().wrap(function _callee45$(_context45) {
+ while (1) switch (_context45.prev = _context45.next) {
+ case 0:
+ return _context45.abrupt("return", (0,_utils_fetch__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .ZP)("/api/online_consults/add_specialists.json", {
+ method: 'post',
+ body: _root_workspace_ppte5yg23_local_v9_test4_node_modules_babel_runtime_7_23_6_babel_runtime_helpers_objectSpread2_js__WEBPACK_IMPORTED_MODULE_1___default()({}, data)
+ }));
+ case 1:
+ case "end":
+ return _context45.stop();
+ }
+ }, _callee45);
+ }));
+ return _add_specialists.apply(this, arguments);
+}
+function getSpecialists(_x46) {
+ return _getSpecialists.apply(this, arguments);
+}
+
+// 删除专家
+function _getSpecialists() {
+ _getSpecialists = _root_workspace_ppte5yg23_local_v9_test4_node_modules_babel_runtime_7_23_6_babel_runtime_helpers_asyncToGenerator_js__WEBPACK_IMPORTED_MODULE_2___default()( /*#__PURE__*/_root_workspace_ppte5yg23_local_v9_test4_node_modules_babel_runtime_7_23_6_babel_runtime_helpers_regeneratorRuntime_js__WEBPACK_IMPORTED_MODULE_0___default()().mark(function _callee46(params) {
+ return _root_workspace_ppte5yg23_local_v9_test4_node_modules_babel_runtime_7_23_6_babel_runtime_helpers_regeneratorRuntime_js__WEBPACK_IMPORTED_MODULE_0___default()().wrap(function _callee46$(_context46) {
+ while (1) switch (_context46.prev = _context46.next) {
+ case 0:
+ return _context46.abrupt("return", (0,_utils_fetch__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .ZP)("/api/online_consults/specialists.json", {
+ method: 'get',
+ params: _root_workspace_ppte5yg23_local_v9_test4_node_modules_babel_runtime_7_23_6_babel_runtime_helpers_objectSpread2_js__WEBPACK_IMPORTED_MODULE_1___default()({}, params)
+ }));
+ case 1:
+ case "end":
+ return _context46.stop();
+ }
+ }, _callee46);
+ }));
+ return _getSpecialists.apply(this, arguments);
+}
+function del_specialist(_x47) {
+ return _del_specialist.apply(this, arguments);
+}
+
+//编辑专家
+function _del_specialist() {
+ _del_specialist = _root_workspace_ppte5yg23_local_v9_test4_node_modules_babel_runtime_7_23_6_babel_runtime_helpers_asyncToGenerator_js__WEBPACK_IMPORTED_MODULE_2___default()( /*#__PURE__*/_root_workspace_ppte5yg23_local_v9_test4_node_modules_babel_runtime_7_23_6_babel_runtime_helpers_regeneratorRuntime_js__WEBPACK_IMPORTED_MODULE_0___default()().mark(function _callee47(data) {
+ return _root_workspace_ppte5yg23_local_v9_test4_node_modules_babel_runtime_7_23_6_babel_runtime_helpers_regeneratorRuntime_js__WEBPACK_IMPORTED_MODULE_0___default()().wrap(function _callee47$(_context47) {
+ while (1) switch (_context47.prev = _context47.next) {
+ case 0:
+ return _context47.abrupt("return", (0,_utils_fetch__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .ZP)("/api/online_consults/del_specialist.json", {
+ method: 'delete',
+ body: _root_workspace_ppte5yg23_local_v9_test4_node_modules_babel_runtime_7_23_6_babel_runtime_helpers_objectSpread2_js__WEBPACK_IMPORTED_MODULE_1___default()({}, data)
+ }));
+ case 1:
+ case "end":
+ return _context47.stop();
+ }
+ }, _callee47);
+ }));
+ return _del_specialist.apply(this, arguments);
+}
+function edit_specialist(_x48) {
+ return _edit_specialist.apply(this, arguments);
+}
+
+//值班信息
+function _edit_specialist() {
+ _edit_specialist = _root_workspace_ppte5yg23_local_v9_test4_node_modules_babel_runtime_7_23_6_babel_runtime_helpers_asyncToGenerator_js__WEBPACK_IMPORTED_MODULE_2___default()( /*#__PURE__*/_root_workspace_ppte5yg23_local_v9_test4_node_modules_babel_runtime_7_23_6_babel_runtime_helpers_regeneratorRuntime_js__WEBPACK_IMPORTED_MODULE_0___default()().mark(function _callee48(data) {
+ return _root_workspace_ppte5yg23_local_v9_test4_node_modules_babel_runtime_7_23_6_babel_runtime_helpers_regeneratorRuntime_js__WEBPACK_IMPORTED_MODULE_0___default()().wrap(function _callee48$(_context48) {
+ while (1) switch (_context48.prev = _context48.next) {
+ case 0:
+ return _context48.abrupt("return", (0,_utils_fetch__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .ZP)("/api/online_consults/edit_specialist.json", {
+ method: 'put',
+ body: _root_workspace_ppte5yg23_local_v9_test4_node_modules_babel_runtime_7_23_6_babel_runtime_helpers_objectSpread2_js__WEBPACK_IMPORTED_MODULE_1___default()({}, data)
+ }));
+ case 1:
+ case "end":
+ return _context48.stop();
+ }
+ }, _callee48);
+ }));
+ return _edit_specialist.apply(this, arguments);
+}
+function get_duty_info(_x49) {
+ return _get_duty_info.apply(this, arguments);
+}
+
+//添加或者取消值班
+function _get_duty_info() {
+ _get_duty_info = _root_workspace_ppte5yg23_local_v9_test4_node_modules_babel_runtime_7_23_6_babel_runtime_helpers_asyncToGenerator_js__WEBPACK_IMPORTED_MODULE_2___default()( /*#__PURE__*/_root_workspace_ppte5yg23_local_v9_test4_node_modules_babel_runtime_7_23_6_babel_runtime_helpers_regeneratorRuntime_js__WEBPACK_IMPORTED_MODULE_0___default()().mark(function _callee49(params) {
+ return _root_workspace_ppte5yg23_local_v9_test4_node_modules_babel_runtime_7_23_6_babel_runtime_helpers_regeneratorRuntime_js__WEBPACK_IMPORTED_MODULE_0___default()().wrap(function _callee49$(_context49) {
+ while (1) switch (_context49.prev = _context49.next) {
+ case 0:
+ return _context49.abrupt("return", (0,_utils_fetch__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .ZP)("/api/online_consults/duty_info.json", {
+ method: 'get',
+ params: _root_workspace_ppte5yg23_local_v9_test4_node_modules_babel_runtime_7_23_6_babel_runtime_helpers_objectSpread2_js__WEBPACK_IMPORTED_MODULE_1___default()({}, params)
+ }));
+ case 1:
+ case "end":
+ return _context49.stop();
+ }
+ }, _callee49);
+ }));
+ return _get_duty_info.apply(this, arguments);
+}
+function add_or_cancel_duty(_x50) {
+ return _add_or_cancel_duty.apply(this, arguments);
+}
+function _add_or_cancel_duty() {
+ _add_or_cancel_duty = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee50(data) {
+ return _regeneratorRuntime().wrap(function _callee50$(_context50) {
+ while (1) switch (_context50.prev = _context50.next) {
+ case 0:
+ return _context50.abrupt("return", Fetch("/api/online_consults/add_or_cancel_duty.json", {
+ method: 'post',
+ body: _objectSpread({}, data)
+ }));
+ case 1:
+ case "end":
+ return _context50.stop();
+ }
+ }, _callee50);
+ }));
+ return _add_or_cancel_duty.apply(this, arguments);
+}
/***/ })
@@ -49,7 +54,7 @@
/* harmony export */ zO: function() { return /* binding */ me_receives_query; }
/* harmony export */ });
-/* unused harmony exports substances_list, code_download, code_batch_download, receives_matches */
+/* unused harmony exports substances_list, code_download, code_batch_download, receives_matches, add_or_cancel_duty */
/* harmony import */ var _root_workspace_ppte5yg23_local_v9_test4_node_modules_babel_runtime_7_23_6_babel_runtime_helpers_regeneratorRuntime_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/_@babel_runtime@7.23.6@@babel/runtime/helpers/regeneratorRuntime.js */ 7557);
/* harmony import */ var _root_workspace_ppte5yg23_local_v9_test4_node_modules_babel_runtime_7_23_6_babel_runtime_helpers_regeneratorRuntime_js__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_root_workspace_ppte5yg23_local_v9_test4_node_modules_babel_runtime_7_23_6_babel_runtime_helpers_regeneratorRuntime_js__WEBPACK_IMPORTED_MODULE_0__);